@@ -3,6 +3,7 @@ import sys
 import time
 import random
 import os
+import platform
 import subprocess
 import pandas as pd
 from random import choice
@@ -154,7 +155,7 @@ def click_n(img_location, n, button='left'):
     print(box_location)
     x_coord = int(float(img.text["offset_x"]))
     y_coord = int(float(img.text["offset_y"]))
-    if os.name == 'posix': # resolution is half the size on macos for some reason
+    if os.name == 'posix' and platform.system() == "Darwin": # resolution is half the size on macos for some reason
         x_coord /= 2
         y_coord /= 2
         x_coord += (box_location.left + box_location.width / 2) / 2
@@ -222,6 +223,32 @@ def remove_char(n=1):
     for x in range(0, n):
         pyautogui.hotkey("backspace")
 
+def copy_to_clipboard():
+    r = tkinter.Tk()
+    r.withdraw()
+    r.clipboard_clear()
+
+    data = sys.stdin.read()
+
+    r.clipboard_append(data)
+
+    if sys.platform != 'win32':
+        if len(sys.argv) > 1:
+            raw_input('Data was copied into clipboard. Paste and press ENTER to exit...')
+        else:
+            # stdin already read; use GUI to exit
+            print('Data was copied into clipboard. Paste, then close popup to exit...')
+            r.deiconify()
+            r.mainloop()
+    else:
+        r.destroy()
+
+def get_clipboard():
+    """
+    Get clipboard text independently from os
+    """
+    return tkinter.Tk().clipboard_get()
+
 ### FILE READ UTILS ###
 def read_excel(path):
     return pd.read_excel(path).to_dict(orient='records')
